# Observability

Logging, monitoring, and observability tools.

## Overview

The observability module provides tools for logging, monitoring, and application observability.

## Components

- **Logfmt**: Logfmt logging format support
- **Setupper**: Observability setup utilities
- **Utils**: Utility functions for observability
